@@ -46,7 +46,7 @@ public:
         Division, IntegerDivision, Exponentiation,
         Super0, Super1, Super2, Super3, Super4,
         Super5, Super6, Super7, Super8, Super9,
-        AssociationStart, AssociationEnd,
+        AssociationStart, AssociationEnd, Percent,
         ListSeparator, Factorial, Assignment, Modulo,
         ArithmeticLeftShift, ArithmeticRightShift,
         BitwiseLogicalAND, BitwiseLogicalOR,
