@@ -11,7 +11,7 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <source>Dark Theme</source>
+        <source>Dark theme</source>
         <translation type="unfinished"></translation>
     </message>
     <message>
