@@ -9,8 +9,8 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <source>Dark Theme</source>
-        <translation>سمة داكنة</translation>
+        <source>Dark theme</source>
+        <translation>السمة الداكنة</translation>
     </message>
     <message>
         <source>Simple mode</source>
@@ -22,11 +22,11 @@
     </message>
     <message>
         <source>Deepin Calculator</source>
-        <translation type="unfinished"/>
+        <translation>حاسبة ديبين</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation type="unfinished"/>
+        <translation>حاسبة ديبين: حاسبة بسيطة وسهلة لاستخدامات سطح المكتب، تدعم عمليات الجمع والطرح والضرب والقسمة.</translation>
     </message>
 </context>
 <context>
