@@ -9,8 +9,8 @@
 <context>
     <name>MainWindow</name>
     <message>
-        <source>Dark Theme</source>
-        <translation>Σκούρο Θέμα</translation>
+        <source>Dark theme</source>
+        <translation>Σκοτεινό θεμα</translation>
     </message>
     <message>
         <source>Simple mode</source>
@@ -22,18 +22,18 @@
     </message>
     <message>
         <source>Deepin Calculator</source>
-        <translation type="unfinished"/>
+        <translation>Αριθμομηχανή Deepin</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation type="unfinished"/>
+        <translation>Η αριθμομηχανή του Deepin είναι μία απλή και εύκολη στην χρήση αριθμομηχανή. Υποστηρίζει πρόσθεση, αφαίρεση, πολλαπλασιασμό και διαίρεση. </translation>
     </message>
 </context>
 <context>
     <name>SimpleListDelegate</name>
     <message>
         <source>Expression Error</source>
-        <translation type="unfinished"/>
+        <translation>Σφάλμα έκφρασης</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
