@@ -3,37 +3,37 @@
     <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation type="unfinished"/>
+        <translation>Lausekkeen virhe</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <source>Dark Theme</source>
-        <translation>Tumma Teema</translation>
+        <source>Dark theme</source>
+        <translation>Tumma teema</translation>
     </message>
     <message>
         <source>Simple mode</source>
-        <translation type="unfinished"/>
+        <translation>Yksinkertainen tila</translation>
     </message>
     <message>
         <source>Scientific mode</source>
-        <translation type="unfinished"/>
+        <translation>Tieteellinen tila</translation>
     </message>
     <message>
         <source>Deepin Calculator</source>
-        <translation type="unfinished"/>
+        <translation>Deepinin Laskin</translation>
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation type="unfinished"/>
+        <translation>Deepinin Laskin on yksinkertainen ja helppokäyttöinen työpöytälaskin. Ohjelma tukee yhteenlaskua, vähennyslaskua, kertolaskua ja jakolaskua.</translation>
     </message>
 </context>
 <context>
     <name>SimpleListDelegate</name>
     <message>
         <source>Expression Error</source>
-        <translation type="unfinished"/>
+        <translation>Lausekkeen virhe</translation>
     </message>
 </context>
 </TS>
\ No newline at end of file
