@@ -3,14 +3,14 @@
     <name>ExpressionBar</name>
     <message>
         <source>Expression Error</source>
-        <translation>Erro de expressão</translation>
+        <translation>Erro de Expressão</translation>
     </message>
 </context>
 <context>
     <name>MainWindow</name>
     <message>
-        <source>Dark Theme</source>
-        <translation>Tema Escuro</translation>
+        <source>Dark theme</source>
+        <translation>Tema escuro</translation>
     </message>
     <message>
         <source>Simple mode</source>
@@ -26,7 +26,7 @@
     </message>
     <message>
         <source>Deepin Calculator is a simple and easy to use desktop calculator. It supports addition, subtraction, multiplication and division.</source>
-        <translation>Deepin Calculator é uma calculadora da área de trabalho simples e fácil de utilizar. Esta suporta a soma, subtração, multiplicação e divisão.</translation>
+        <translation>Deepin Calculator é uma calculadora de ambiente de trabalho simples e fácil de utilizar. Suporta soma, subtração, multiplicação e divisão.</translation>
     </message>
 </context>
 <context>
